@@ -97,6 +97,7 @@ import aws_cdk.aws_apigateway
 import aws_cdk.aws_cognito
 import aws_cdk.aws_dynamodb
 import aws_cdk.aws_ec2
+import aws_cdk.aws_glue
 import aws_cdk.aws_iam
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_kinesisfirehose
@@ -186,70 +187,70 @@ class AddProxyMethodToApiResourceInputParams:
     def api_gateway_role(self) -> aws_cdk.aws_iam.IRole:
         result = self._values.get("api_gateway_role")
         assert result is not None, "Required property 'api_gateway_role' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_iam.IRole, result)
 
     @builtins.property
     def api_method(self) -> builtins.str:
         result = self._values.get("api_method")
         assert result is not None, "Required property 'api_method' is missing"
-        return result
+        return typing.cast(builtins.str, result)
 
     @builtins.property
     def api_resource(self) -> aws_cdk.aws_apigateway.IResource:
         result = self._values.get("api_resource")
         assert result is not None, "Required property 'api_resource' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_apigateway.IResource, result)
 
     @builtins.property
     def request_template(self) -> builtins.str:
         result = self._values.get("request_template")
         assert result is not None, "Required property 'request_template' is missing"
-        return result
+        return typing.cast(builtins.str, result)
 
     @builtins.property
     def service(self) -> builtins.str:
         result = self._values.get("service")
         assert result is not None, "Required property 'service' is missing"
-        return result
+        return typing.cast(builtins.str, result)
 
     @builtins.property
     def action(self) -> typing.Optional[builtins.str]:
         result = self._values.get("action")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def aws_integration_props(self) -> typing.Any:
         result = self._values.get("aws_integration_props")
-        return result
+        return typing.cast(typing.Any, result)
 
     @builtins.property
     def content_type(self) -> typing.Optional[builtins.str]:
         result = self._values.get("content_type")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def method_options(self) -> typing.Optional[aws_cdk.aws_apigateway.MethodOptions]:
         result = self._values.get("method_options")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_apigateway.MethodOptions], result)
 
     @builtins.property
     def path(self) -> typing.Optional[builtins.str]:
         result = self._values.get("path")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def request_model(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_apigateway.IModel]]:
         result = self._values.get("request_model")
-        return result
+        return typing.cast(typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_apigateway.IModel]], result)
 
     @builtins.property
     def request_validator(
         self,
     ) -> typing.Optional[aws_cdk.aws_apigateway.IRequestValidator]:
         result = self._values.get("request_validator")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_apigateway.IRequestValidator], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -307,7 +308,7 @@ class BuildDeadLetterQueueProps:
         :default: - Default props are used
         """
         result = self._values.get("dead_letter_queue_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
 
     @builtins.property
     def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
@@ -316,7 +317,7 @@ class BuildDeadLetterQueueProps:
         :default: - required field.
         """
         result = self._values.get("deploy_dead_letter_queue")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
@@ -325,7 +326,7 @@ class BuildDeadLetterQueueProps:
         :default: - None.
         """
         result = self._values.get("existing_queue_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], result)
 
     @builtins.property
     def max_receive_count(self) -> typing.Optional[jsii.Number]:
@@ -334,7 +335,7 @@ class BuildDeadLetterQueueProps:
         :default: - Default props are used
         """
         result = self._values.get("max_receive_count")
-        return result
+        return typing.cast(typing.Optional[jsii.Number], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -382,7 +383,7 @@ class BuildDynamoDBTableProps:
         :default: - Default props are used
         """
         result = self._values.get("dynamo_table_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.TableProps], result)
 
     @builtins.property
     def existing_table_obj(self) -> typing.Optional[aws_cdk.aws_dynamodb.Table]:
@@ -393,7 +394,7 @@ class BuildDynamoDBTableProps:
         :default: - None
         """
         result = self._values.get("existing_table_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_dynamodb.Table], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -407,6 +408,91 @@ class BuildDynamoDBTableProps:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.BuildGlueJobProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "database": "database",
+        "table": "table",
+        "existing_cfn_job": "existingCfnJob",
+        "glue_job_props": "glueJobProps",
+        "output_data_store": "outputDataStore",
+    },
+)
+class BuildGlueJobProps:
+    def __init__(
+        self,
+        *,
+        database: aws_cdk.aws_glue.CfnDatabase,
+        table: aws_cdk.aws_glue.CfnTable,
+        existing_cfn_job: typing.Optional[aws_cdk.aws_glue.CfnJob] = None,
+        glue_job_props: typing.Any = None,
+        output_data_store: typing.Optional["SinkDataStoreProps"] = None,
+    ) -> None:
+        """
+        :param database: AWS Glue database.
+        :param table: AWS Glue table.
+        :param existing_cfn_job: Existing instance of the S3 bucket object, if this is set then the script location is ignored.
+        :param glue_job_props: Glue ETL job properties.
+        :param output_data_store: Output storage options.
+        """
+        if isinstance(output_data_store, dict):
+            output_data_store = SinkDataStoreProps(**output_data_store)
+        self._values: typing.Dict[str, typing.Any] = {
+            "database": database,
+            "table": table,
+        }
+        if existing_cfn_job is not None:
+            self._values["existing_cfn_job"] = existing_cfn_job
+        if glue_job_props is not None:
+            self._values["glue_job_props"] = glue_job_props
+        if output_data_store is not None:
+            self._values["output_data_store"] = output_data_store
+
+    @builtins.property
+    def database(self) -> aws_cdk.aws_glue.CfnDatabase:
+        """AWS Glue database."""
+        result = self._values.get("database")
+        assert result is not None, "Required property 'database' is missing"
+        return typing.cast(aws_cdk.aws_glue.CfnDatabase, result)
+
+    @builtins.property
+    def table(self) -> aws_cdk.aws_glue.CfnTable:
+        """AWS Glue table."""
+        result = self._values.get("table")
+        assert result is not None, "Required property 'table' is missing"
+        return typing.cast(aws_cdk.aws_glue.CfnTable, result)
+
+    @builtins.property
+    def existing_cfn_job(self) -> typing.Optional[aws_cdk.aws_glue.CfnJob]:
+        """Existing instance of the S3 bucket object, if this is set then the script location is ignored."""
+        result = self._values.get("existing_cfn_job")
+        return typing.cast(typing.Optional[aws_cdk.aws_glue.CfnJob], result)
+
+    @builtins.property
+    def glue_job_props(self) -> typing.Any:
+        """Glue ETL job properties."""
+        result = self._values.get("glue_job_props")
+        return typing.cast(typing.Any, result)
+
+    @builtins.property
+    def output_data_store(self) -> typing.Optional["SinkDataStoreProps"]:
+        """Output storage options."""
+        result = self._values.get("output_data_store")
+        return typing.cast(typing.Optional["SinkDataStoreProps"], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "BuildGlueJobProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/core.BuildKinesisAnalyticsAppProps",
     jsii_struct_bases=[],
@@ -440,7 +526,7 @@ class BuildKinesisAnalyticsAppProps:
         """
         result = self._values.get("kinesis_firehose")
         assert result is not None, "Required property 'kinesis_firehose' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_kinesisfirehose.CfnDeliveryStream, result)
 
     @builtins.property
     def kinesis_analytics_props(self) -> typing.Any:
@@ -449,7 +535,7 @@ class BuildKinesisAnalyticsAppProps:
         :default: - Default props are used
         """
         result = self._values.get("kinesis_analytics_props")
-        return result
+        return typing.cast(typing.Any, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -497,7 +583,7 @@ class BuildKinesisStreamProps:
         :default: - None
         """
         result = self._values.get("existing_stream_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.Stream], result)
 
     @builtins.property
     def kinesis_stream_props(self) -> typing.Optional[aws_cdk.aws_kinesis.StreamProps]:
@@ -506,7 +592,7 @@ class BuildKinesisStreamProps:
         :default: - Default props are used.
         """
         result = self._values.get("kinesis_stream_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kinesis.StreamProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -559,7 +645,7 @@ class BuildLambdaFunctionProps:
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.Function], result)
 
     @builtins.property
     def lambda_function_props(
@@ -570,7 +656,7 @@ class BuildLambdaFunctionProps:
         :default: - Default props are used
         """
         result = self._values.get("lambda_function_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.FunctionProps], result)
 
     @builtins.property
     def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
@@ -579,7 +665,7 @@ class BuildLambdaFunctionProps:
         :default: - none
         """
         result = self._values.get("vpc")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -651,7 +737,7 @@ class BuildQueueProps:
         :default: - Default props are used.
         """
         result = self._values.get("dead_letter_queue")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], result)
 
     @builtins.property
     def enable_encryption_with_customer_managed_key(
@@ -665,7 +751,7 @@ class BuildQueueProps:
         :default: - false (encryption enabled with AWS Managed KMS Key).
         """
         result = self._values.get("enable_encryption_with_customer_managed_key")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
@@ -674,7 +760,7 @@ class BuildQueueProps:
         :default: - not specified.
         """
         result = self._values.get("encryption_key")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
 
     @builtins.property
     def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
@@ -683,7 +769,7 @@ class BuildQueueProps:
         :default: - Ignored if encryptionKey is provided
         """
         result = self._values.get("encryption_key_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
 
     @builtins.property
     def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
@@ -692,7 +778,7 @@ class BuildQueueProps:
         :default: - None.
         """
         result = self._values.get("existing_queue_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], result)
 
     @builtins.property
     def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
@@ -701,7 +787,7 @@ class BuildQueueProps:
         :default: - Default props are used.
         """
         result = self._values.get("queue_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -742,7 +828,7 @@ class BuildS3BucketProps:
         :default: - Default props are used
         """
         result = self._values.get("bucket_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -799,7 +885,7 @@ class BuildSagemakerNotebookProps:
         """
         result = self._values.get("role")
         assert result is not None, "Required property 'role' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_iam.Role, result)
 
     @builtins.property
     def deploy_inside_vpc(self) -> typing.Optional[builtins.bool]:
@@ -808,7 +894,7 @@ class BuildSagemakerNotebookProps:
         :default: - true
         """
         result = self._values.get("deploy_inside_vpc")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def existing_notebook_obj(
@@ -821,7 +907,7 @@ class BuildSagemakerNotebookProps:
         :default: - None
         """
         result = self._values.get("existing_notebook_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sagemaker.CfnNotebookInstance], result)
 
     @builtins.property
     def sagemaker_notebook_props(self) -> typing.Any:
@@ -830,7 +916,7 @@ class BuildSagemakerNotebookProps:
         :default: - Default props are used
         """
         result = self._values.get("sagemaker_notebook_props")
-        return result
+        return typing.cast(typing.Any, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -900,7 +986,7 @@ class BuildTopicProps:
         :default: - false (encryption enabled with AWS Managed KMS Key).
         """
         result = self._values.get("enable_encryption_with_customer_managed_key")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
@@ -909,7 +995,7 @@ class BuildTopicProps:
         :default: - not specified.
         """
         result = self._values.get("encryption_key")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
 
     @builtins.property
     def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
@@ -918,7 +1004,7 @@ class BuildTopicProps:
         :default: - Ignored if encryptionKey is provided
         """
         result = self._values.get("encryption_key_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
 
     @builtins.property
     def existing_topic_obj(self) -> typing.Optional[aws_cdk.aws_sns.Topic]:
@@ -927,7 +1013,7 @@ class BuildTopicProps:
         :default: - None.
         """
         result = self._values.get("existing_topic_obj")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sns.Topic], result)
 
     @builtins.property
     def topic_props(self) -> typing.Optional[aws_cdk.aws_sns.TopicProps]:
@@ -936,7 +1022,7 @@ class BuildTopicProps:
         :default: - Default props are used.
         """
         result = self._values.get("topic_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sns.TopicProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -996,25 +1082,25 @@ class BuildVpcProps:
         """One of the default VPC configurations available in vpc-defaults."""
         result = self._values.get("default_vpc_props")
         assert result is not None, "Required property 'default_vpc_props' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_ec2.VpcProps, result)
 
     @builtins.property
     def construct_vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
         """Construct specified props that override both the default props and user props for the VPC."""
         result = self._values.get("construct_vpc_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
 
     @builtins.property
     def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
         """Existing instance of a VPC, if this is set then the all Props are ignored."""
         result = self._values.get("existing_vpc")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
 
     @builtins.property
     def user_vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
         """User provided props to override the default props for the VPC."""
         result = self._values.get("user_vpc_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1065,24 +1151,24 @@ class CfnDomainOptions:
     def cognito_authorized_role_arn(self) -> builtins.str:
         result = self._values.get("cognito_authorized_role_arn")
         assert result is not None, "Required property 'cognito_authorized_role_arn' is missing"
-        return result
+        return typing.cast(builtins.str, result)
 
     @builtins.property
     def identitypool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
         result = self._values.get("identitypool")
         assert result is not None, "Required property 'identitypool' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_cognito.CfnIdentityPool, result)
 
     @builtins.property
     def userpool(self) -> aws_cdk.aws_cognito.UserPool:
         result = self._values.get("userpool")
         assert result is not None, "Required property 'userpool' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_cognito.UserPool, result)
 
     @builtins.property
     def service_role_arn(self) -> typing.Optional[builtins.str]:
         result = self._values.get("service_role_arn")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1128,19 +1214,19 @@ class CognitoOptions:
     def identitypool(self) -> aws_cdk.aws_cognito.CfnIdentityPool:
         result = self._values.get("identitypool")
         assert result is not None, "Required property 'identitypool' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_cognito.CfnIdentityPool, result)
 
     @builtins.property
     def userpool(self) -> aws_cdk.aws_cognito.UserPool:
         result = self._values.get("userpool")
         assert result is not None, "Required property 'userpool' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_cognito.UserPool, result)
 
     @builtins.property
     def userpoolclient(self) -> aws_cdk.aws_cognito.UserPoolClient:
         result = self._values.get("userpoolclient")
         assert result is not None, "Required property 'userpoolclient' is missing"
-        return result
+        return typing.cast(aws_cdk.aws_cognito.UserPoolClient, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1191,19 +1277,19 @@ class EventSourceProps:
     @builtins.property
     def deploy_sqs_dlq_queue(self) -> typing.Optional[builtins.bool]:
         result = self._values.get("deploy_sqs_dlq_queue")
-        return result
+        return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
     def event_source_props(
         self,
     ) -> typing.Optional[aws_cdk.aws_lambda_event_sources.StreamEventSourceProps]:
         result = self._values.get("event_source_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda_event_sources.StreamEventSourceProps], result)
 
     @builtins.property
     def sqs_dlq_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
         result = self._values.get("sqs_dlq_queue_props")
-        return result
+        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -1217,6 +1303,74 @@ class EventSourceProps:
         )
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.SecurityGroupRuleDefinition",
+    jsii_struct_bases=[],
+    name_mapping={
+        "connection": "connection",
+        "peer": "peer",
+        "description": "description",
+        "remote_rule": "remoteRule",
+    },
+)
+class SecurityGroupRuleDefinition:
+    def __init__(
+        self,
+        *,
+        connection: aws_cdk.aws_ec2.Port,
+        peer: aws_cdk.aws_ec2.IPeer,
+        description: typing.Optional[builtins.str] = None,
+        remote_rule: typing.Optional[builtins.bool] = None,
+    ) -> None:
+        """
+        :param connection: -
+        :param peer: -
+        :param description: -
+        :param remote_rule: -
+        """
+        self._values: typing.Dict[str, typing.Any] = {
+            "connection": connection,
+            "peer": peer,
+        }
+        if description is not None:
+            self._values["description"] = description
+        if remote_rule is not None:
+            self._values["remote_rule"] = remote_rule
+
+    @builtins.property
+    def connection(self) -> aws_cdk.aws_ec2.Port:
+        result = self._values.get("connection")
+        assert result is not None, "Required property 'connection' is missing"
+        return typing.cast(aws_cdk.aws_ec2.Port, result)
+
+    @builtins.property
+    def peer(self) -> aws_cdk.aws_ec2.IPeer:
+        result = self._values.get("peer")
+        assert result is not None, "Required property 'peer' is missing"
+        return typing.cast(aws_cdk.aws_ec2.IPeer, result)
+
+    @builtins.property
+    def description(self) -> typing.Optional[builtins.str]:
+        result = self._values.get("description")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def remote_rule(self) -> typing.Optional[builtins.bool]:
+        result = self._values.get("remote_rule")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "SecurityGroupRuleDefinition(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
 @jsii.enum(jsii_type="@aws-solutions-constructs/core.ServiceEndpointTypes")
 class ServiceEndpointTypes(enum.Enum):
     DYNAMODB = "DYNAMODB"
@@ -1226,10 +1380,102 @@ class ServiceEndpointTypes(enum.Enum):
     STEPFUNCTIONS = "STEPFUNCTIONS"
 
 
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/core.SinkDataStoreProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "datastore_type": "datastoreType",
+        "existing_s3_output_bucket": "existingS3OutputBucket",
+        "output_bucket_props": "outputBucketProps",
+    },
+)
+class SinkDataStoreProps:
+    def __init__(
+        self,
+        *,
+        datastore_type: "SinkStoreType",
+        existing_s3_output_bucket: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+        output_bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
+    ) -> None:
+        """Interface to define potential outputs to allow the construct define additional output destinations for ETL transformation.
+
+        :param datastore_type: Sink data store type.
+        :param existing_s3_output_bucket: The output S3 location where the data should be written. The provided S3 bucket will be used to pass the output location to the etl script as an argument to the AWS Glue job. If no location is provided, it will check if @outputBucketProps are provided. If not it will create a new bucket if the @datastoreType is S3. The argument key is ``output_path``. The value of the argument can be retrieve in the python script as follows: getResolvedOptions(sys.argv, ["JOB_NAME", "output_path", ]) output_path = args["output_path"]
+        :param output_bucket_props: If @existingS3OutputBUcket is provided, this parameter is ignored. If this parameter is not provided, the construct will create a new bucket if the @datastoreType is S3.
+        """
+        if isinstance(output_bucket_props, dict):
+            output_bucket_props = aws_cdk.aws_s3.BucketProps(**output_bucket_props)
+        self._values: typing.Dict[str, typing.Any] = {
+            "datastore_type": datastore_type,
+        }
+        if existing_s3_output_bucket is not None:
+            self._values["existing_s3_output_bucket"] = existing_s3_output_bucket
+        if output_bucket_props is not None:
+            self._values["output_bucket_props"] = output_bucket_props
+
+    @builtins.property
+    def datastore_type(self) -> "SinkStoreType":
+        """Sink data store type."""
+        result = self._values.get("datastore_type")
+        assert result is not None, "Required property 'datastore_type' is missing"
+        return typing.cast("SinkStoreType", result)
+
+    @builtins.property
+    def existing_s3_output_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        """The output S3 location where the data should be written.
+
+        The provided S3 bucket will be used to pass
+        the output location to the etl script as an argument to the AWS Glue job.
+
+        If no location is provided, it will check if @outputBucketProps are provided. If not it will create a new
+        bucket if the @datastoreType is S3.
+
+        The argument key is ``output_path``. The value of the argument can be retrieve in the python script
+        as follows:
+        getResolvedOptions(sys.argv, ["JOB_NAME", "output_path",  ])
+        output_path = args["output_path"]
+        """
+        result = self._values.get("existing_s3_output_bucket")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.Bucket], result)
+
+    @builtins.property
+    def output_bucket_props(self) -> typing.Optional[aws_cdk.aws_s3.BucketProps]:
+        """If @existingS3OutputBUcket is provided, this parameter is ignored.
+
+        If this parameter is not provided,
+        the construct will create a new bucket if the @datastoreType is S3.
+        """
+        result = self._values.get("output_bucket_props")
+        return typing.cast(typing.Optional[aws_cdk.aws_s3.BucketProps], result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "SinkDataStoreProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
+
+
+@jsii.enum(jsii_type="@aws-solutions-constructs/core.SinkStoreType")
+class SinkStoreType(enum.Enum):
+    """Enumeration of data store types that could include S3, DynamoDB, DocumentDB, RDS or Redshift.
+
+    Current
+    construct implementation only supports S3, but potential to add other output types in the future
+    """
+
+    S3 = "S3"
+
+
 __all__ = [
     "AddProxyMethodToApiResourceInputParams",
     "BuildDeadLetterQueueProps",
     "BuildDynamoDBTableProps",
+    "BuildGlueJobProps",
     "BuildKinesisAnalyticsAppProps",
     "BuildKinesisStreamProps",
     "BuildLambdaFunctionProps",
@@ -1241,7 +1487,10 @@ __all__ = [
     "CfnDomainOptions",
     "CognitoOptions",
     "EventSourceProps",
+    "SecurityGroupRuleDefinition",
     "ServiceEndpointTypes",
+    "SinkDataStoreProps",
+    "SinkStoreType",
 ]
 
 publication.publish()
