@@ -18,6 +18,7 @@ import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_elasticsearch._jsii
 import aws_cdk.aws_events._jsii
+import aws_cdk.aws_glue._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_iot._jsii
 import aws_cdk.aws_kinesis._jsii
@@ -29,6 +30,7 @@ import aws_cdk.aws_lambda_event_sources._jsii
 import aws_cdk.aws_logs._jsii
 import aws_cdk.aws_mediastore._jsii
 import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_s3_assets._jsii
 import aws_cdk.aws_s3_notifications._jsii
 import aws_cdk.aws_sagemaker._jsii
 import aws_cdk.aws_sns._jsii
@@ -37,7 +39,7 @@ import aws_cdk.aws_stepfunctions._jsii
 import aws_cdk.core._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-solutions-constructs/core", "1.81.0", __name__[0:-6], "core@1.81.0.jsii.tgz"
+    "@aws-solutions-constructs/core", "1.86.0", __name__[0:-6], "core@1.86.0.jsii.tgz"
 )
 
 __all__ = [
